==> dif-database-repository-2.7.1-sources.jar: pt/digitalis/dif/dem/managers/impl/model/impl/AccessLogServiceImpl.java <==
package pt.digitalis.dif.dem.managers.impl.model.impl;

import pt.digitalis.dif.model.hibernate.HibernateUtil;
import pt.digitalis.dif.model.dataset.IDataSet;
import pt.digitalis.dif.model.dataset.HibernateDataSet;
import pt.digitalis.dif.model.dataset.HibernateDataSetLegacyNoPK;
import pt.digitalis.utils.common.IBeanAttributes;

import pt.digitalis.dif.dem.managers.impl.model.DIFRepositoryFactory;
import pt.digitalis.dif.dem.managers.impl.model.IAccessLogService;
import pt.digitalis.dif.dem.managers.impl.model.data.AccessLog;

/**
* NOTE: This file is auto generated and will be overwrite in a future file generation.
*/
public class AccessLogServiceImpl implements IAccessLogService {

    /**
     * Obtains a new DataSet for the AccessLog entity
     *
     * @return A new HibernateDataSet instance
     */
    public HibernateDataSet<AccessLog> getAccessLogDataSet() {
        return new HibernateDataSet<AccessLog>(AccessLog.class, HibernateUtil.getSessionFactory("DIFRepository"),
                AccessLog.getPKFieldListAsString(), AccessLog.FieldAttributes);
    }

    /**
     * Obtains a IDataSet for the given entity class
     *
     * @param clazz
     *            the entity class
     * @return A new IDataSet instance
     */
    public HibernateDataSet<? extends IBeanAttributes> getDataSet(Class<? extends IBeanAttributes> clazz) {

        if (clazz == AccessLog.class)
            return getAccessLogDataSet();

        return null;
    }

    /**
     * Obtains a IDataSet for the given entity class
     *
     * @param entityName
     *            the entity class simple name
     * @return A new IDataSet instance
     */
    public HibernateDataSet<? extends IBeanAttributes> getDataSet(String entityName) {

        if (entityName.equalsIgnoreCase(AccessLog.class.getSimpleName()))
            return getAccessLogDataSet();

        return null;
    }
}

==> dif-database-repository-2.7.3-5-sources.jar: pt/digitalis/dif/dem/managers/impl/model/impl/AccessLogServiceImpl.java <==
package pt.digitalis.dif.dem.managers.impl.model.impl;

import pt.digitalis.dif.model.hibernate.HibernateUtil;
import pt.digitalis.dif.model.dataset.IDataSet;
import pt.digitalis.dif.model.dataset.HibernateDataSet;
import pt.digitalis.dif.model.dataset.HibernateDataSetLegacyNoPK;
import pt.digitalis.utils.common.IBeanAttributes;

import pt.digitalis.dif.dem.managers.impl.model.DIFRepositoryFactory;
import pt.digitalis.dif.dem.managers.impl.model.IAccessLogService;
import pt.digitalis.dif.dem.managers.impl.model.data.AccessLog;

/**
* NOTE: This file is auto generated and will be overwrite in a future file generation.
*/
public class AccessLogServiceImpl implements IAccessLogService {

    /**
     * Constant with the session factory ID
     */
    public static String SESSION_FACTORY_NAME = "DIFRepository";

    /**
     * Obtains a new DataSet for the AccessLog entity
     *
     * @return A new HibernateDataSet instance
     */
    public HibernateDataSet<AccessLog> getAccessLogDataSet() {
        return new HibernateDataSet<AccessLog>(AccessLog.class, HibernateUtil.getSessionFactory(SESSION_FACTORY_NAME),
                AccessLog.getPKFieldListAsString(), AccessLog.FieldAttributes);
    }

    /**
     * Obtains a IDataSet for the given entity class
     *
     * @param clazz
     *            the entity class
     * @return A new IDataSet instance
     */
    public HibernateDataSet<? extends IBeanAttributes> getDataSet(Class<? extends IBeanAttributes> clazz) {

        if (clazz == AccessLog.class)
            return getAccessLogDataSet();

        return null;
    }

    /**
     * Obtains a IDataSet for the given entity class
     *
     * @param entityName
     *            the entity class simple name
     * @return A new IDataSet instance
     */
    public HibernateDataSet<? extends IBeanAttributes> getDataSet(String entityName) {

        if (entityName.equalsIgnoreCase(AccessLog.class.getSimpleName()))
            return getAccessLogDataSet();

        return null;
    }
}
